@@ -2,8 +2,8 @@
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: email-validate
 version: 2.2.0
-id: email-validate-2.2.0-c5aad21ab9e6d2698dc2a27bb770c994
-key: email_IFch01HiPb536WIfX9xYDP
+id: email-validate-2.2.0-894e6c8f7fbbeb1604af196a15c5e993
+key: email_9Ysbd19b8HJB8wjaRZW71w
 license: BSD3
 maintainer: George Pollard <porges@porg.es>
 stability: experimental
@@ -20,9 +20,9 @@ trusted: False
 import-dirs: /usr/lib/ghc-7.10.3/site-local/email-validate-2.2.0
 library-dirs: /usr/lib/ghc-7.10.3/site-local/email-validate-2.2.0
 data-dir: /usr/share/arm-linux-ghc-7.10.3/email-validate-2.2.0
-hs-libraries: HSemail-validate-2.2.0-IFch01HiPb536WIfX9xYDP
+hs-libraries: HSemail-validate-2.2.0-9Ysbd19b8HJB8wjaRZW71w
 depends:
-    attoparsec-0.13.0.1-57451b44323b331c08be1b712bdc3810
+    attoparsec-0.13.0.1-cc18275e376dae94cc21e54b8b072afd
     base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
     bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
     ghc-prim-0.4.0.0-bf246eb9fdda7435f0c147a313ce59fb
